@@ -1,13 +1,15 @@
-#!/usr/bin/env python3.8
+#!/usr/bin/env python
 
-from uacs import function
+from uacs.function import *
+from uacs.uacs import *
 import time
 
+running = True
 
-def main():
+
+def run_daemon():
     print("Starting...")
     function.restore(True)
-    running = True
     print("Started !")
     while running:
         time.sleep(30)
@@ -18,4 +20,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    run_daemon()
